import { Mail, Phone } from "lucide-react";
import { useLocale } from "next-intl";

import LanguageSwitcherSelect from "@/components/common/testings/language-switcher-select";
import { routing } from "@/i18n/routing";

import SocialMedia from "./social-media";

export default function TopBar() {
	const locale = useLocale();
	return (
		<section className="bg-custom-secondary px-4 sm:px-8 md:px-16 lg:px-24">
			<div className="mx-auto flex h-auto w-full max-w-10xl flex-col-reverse items-center justify-between  md:h-[56px] md:flex-row">
				<div className="flex items-center gap-2 sm:gap-4 md:gap-6">
					<LanguageSwitcherSelect defaultValue={locale} label="Select a locale">
						{routing.locales?.map((cur) => (
							<option key={cur} value={cur}>
								<p className="text-xs text-custom-background-light sm:text-sm">
									{cur == "ar" ? "العربية" : "English"}
								</p>
							</option>
						))}
					</LanguageSwitcherSelect>

					<div className="h-[27px] w-[1px] bg-[#B4BCD2]" />

					<div className="flex items-center gap-1 sm:gap-2">
						<p className="text-xs text-custom-background-light sm:text-sm">
							920013334
						</p>
						<Phone className="text-custom-background-light" />
					</div>

					<div className="h-[27px] w-[1px] bg-[#B4BCD2]" />

					<div className="flex items-center gap-1 sm:gap-2">
						<p className="text-xs text-custom-background-light sm:text-sm">
							bintaleb@bintaleb.com
						</p>
						<Mail className="text-custom-background-light" />
					</div>
				</div>
				<div>
					<SocialMedia />
				</div>
			</div>
		</section>
	);
}
